@@ -103,14 +103,6 @@ sub ldd
 
     my %dlls = $out =~ /^ \s* (\S+) \s* => \s* (\S+) /gmx;
 
-    use Data::Dumper;
-    my $debug = "--- ldd $file ---\n"
-                .$out
-                ."--- %dlls ---\n"
-                .Dumper(\%dlls);
-    $debug =~ s/^/# /gm;
-    print STDERR $debug;
-
     # weed out system libraries (except the perl shared library)
     while (my ($name, $path) = each %dlls)
     {
